Create a simple dashboard based on Bootstrap templates.

This is a bokeh directory application. To run it, enter the following command at a Bash or Windows command prompt:

```{bash}
bokeh serve --show dash
```

See also the [users guide on bokeh directory applications](https://bokeh.pydata.org/en/latest/docs/user_guide/server.html#directory-format), for more detail.

# Licences

This example uses vendored code from the following projects:

* https://fontawesome.com/license

* https://getbootstrap.com/docs/3.3/getting-started/

* https://github.com/puikinsh/gentelella/blob/master/LICENSE.txt
